#!/usr/bin/env python

#TEST

import unittest
from Numeric import allclose

from alpha_shape import *

class TestCase(unittest.TestCase):

    def setUp(self):
        pass

         
    def tearDown(self):
        pass

    def test_delaunay(self):
        #print "test_delaunay"
        a = [0.0, 0.0]
        b = [1.0, 0.0]
        c = [2.0, 0.0]
        d = [2.0, 2.0]
        e = [1.0, 2.0]
        f = [0.0, 2.0]

        alpha = Alpha_Shape([a,b,c,d,e,f])
        result = alpha.get_delaunay()
        answer = [(0, 1, 5), (5, 1, 4), (4, 2, 3), (2, 4, 1)]
        # print "result",result
        assert allclose(answer, result) 


    def test_alpha_1(self):
        #print "test_alpha" 
        a = [0.0, 0.0]
        b = [1.0, 0.0]
        c = [2.0, 0.0]
        d = [2.0, 2.0]
        e = [1.0, 2.0]
        f = [0.0, 2.0]

        alpha = Alpha_Shape([a,b,c,d,e,f])
        result = alpha.get_boundary()
        #print "result",result
        answer = [(5, 0), (0, 1), (4, 5), (2, 3), (3, 4), (1, 2)]
        assert allclose(answer, result) 


    def test_alpha_2(self):
        #print "test_alpha" 
        a = [0.0, 0.0]
        b = [2.0, 0.0]
        c = [4.0, 0.0]
        cd = [3.0,2.0]
        d = [4.0, 4.0]
        e = [2.0, 4.0]
        f = [0.0, 4.0]

        alpha = Alpha_Shape([a,b,c,cd,d,e,f])
        result = alpha.get_boundary()
        #print "result",result
        answer = [(0, 3), (3, 6), (0, 1), (1, 2), (2, 3), (3, 4), (4, 5), (5, 6)]
        assert allclose(answer, result) 


    def test_alpha_3(self):
        #print "test_alpha" 
        a = [0.0, 0.0]
        b = [1.0, 0.0]
        c = [2.0, 0.0]
        d = [2.0, 2.0]
        e = [1.0, 2.0]
        f = [0.0, 2.0]
        alf = 1.5

        alpha = Alpha_Shape([a,b,c,d,e,f],alf)
        result = alpha.get_boundary()
        #print "result",result
        answer = [(5, 0), (0, 1), (4, 5), (2, 3), (3, 4), (1, 2)]
        assert allclose(answer, result) 


        
    def test_not_enough_points(self):
        #print "test_not_enought_points"
        a = [0.0, 0.0]
        b = [1.0, 0.0]

        try:
            alpha = Alpha_Shape([a,b])
        except PointError:
            pass
        else:
            self.failUnless(0==1,
                        'point list with 2 points did not raise an error!')


    def test_alpha_stand_alone(self):
        #print "test_alpha_stand_alone"
        import os
        import tempfile

        fileName = tempfile.mktemp(".xya")
        #(h,fileName) = tempfile.mkstemp(".xya") 
        file = open(fileName,"w")
        file.write("title row \n\
0.0, 0.0\n\
1.0, 0.0\n\
2.0, 0.0\n\
2.0, 2.0\n\
1.0, 2.0\n\
0.0, 2.0\n")
        file.close()

        output_file_name = tempfile.mktemp(".bnd")
        #(ho, output_file_name) = tempfile.mkstemp(".bnd")
        command = 'python alpha_shape.py ' + fileName + ' ' + output_file_name
        #print "command", command
        os.system(command)
        os.remove(fileName)
        
        file = open(output_file_name,"r")
        lFile = file.read().split('\n')
        file.close()
        os.remove(output_file_name)
        self.failUnless(lFile[1] == "5,0" and
                        lFile[2] == "0,1" and 
                        lFile[3] == "4,5" and 
                        lFile[4] == "2,3" and 
                        lFile[5] == "3,4" and 
                        lFile[6] == "1,2" and 
                        lFile[7] == ""
                        ,
                        'boundary file is wrong')


#-------------------------------------------------------------
if __name__ == "__main__":
    #print "starting tests \n"
    suite = unittest.makeSuite(TestCase,'test')
    runner = unittest.TextTestRunner(verbosity=1)
    runner.run(suite)
    #print "finished tests \n"
    

    
    



